@@ -1,20 +1,5 @@
-/*
-Copyright (C) 2001 - 2013 Evan Teran
-                          evan.teran@gmail.com
-
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2001-2013 Evan Teran <evan.teran@gmail.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "knumber_integer.h"
 #include "knumber_float.h"
@@ -144,8 +129,8 @@ knumber_base *knumber_float::clone() {
 }
 
 mpfr_ptr knumber_float::new_mpfr() {
-	mpfr_init(mpfr_);
-	return mpfr_;
+    mpfr_init2(mpfr_, precision);
+    return mpfr_;
 }
 
 //------------------------------------------------------------------------------
@@ -576,20 +561,20 @@ QString knumber_float::toString(int precision) const {
 	size_t size;
 
 	if (precision > 0) {
-		size = static_cast<size_t>(mpfr_snprintf(nullptr, 0, "%.*Rg", precision, mpfr_) + 1);
-	} else {
-		size = static_cast<size_t>(mpfr_snprintf(nullptr, 0, "%.Rg", mpfr_) + 1);
-	}
+        size = static_cast<size_t>(mpfr_snprintf(nullptr, 0, "%.*Rg", precision, mpfr_) + 1);
+    } else {
+        size = static_cast<size_t>(mpfr_snprintf(nullptr, 0, "%.Rg", mpfr_) + 1);
+    }
 
-	QScopedArrayPointer<char> buf(new char[size]);
+    QScopedArrayPointer<char> buf(new char[size]);
 
-	if (precision > 0) {
-		mpfr_snprintf(&buf[0], size, "%.*Rg", precision, mpfr_);
-	} else {
-		mpfr_snprintf(&buf[0], size, "%.Rg", mpfr_);
-	}
+    if (precision > 0) {
+        mpfr_snprintf(&buf[0], size, "%.*Rg", precision, mpfr_);
+    } else {
+        mpfr_snprintf(&buf[0], size, "%.Rg", mpfr_);
+    }
 
-	return QLatin1String(&buf[0]);
+    return QLatin1String(&buf[0]);
 }
 
 QString knumber_float::toBinaryString(int precision) const {
